Placement

Enum Placement 

pub enum Placement {
    TopLeft,
    TopCenter,
    TopRight,
    RightTop,
    RightCenter,
    RightBottom,
    BottomRight,
    BottomCenter,
    BottomLeft,
    LeftBottom,
    LeftCenter,
    LeftTop,
}
Describes which edge of trigger the menu is anchored to, and where along that edge it is placed.

Variant names are EdgePosition:

  • Edge is the side of trigger the menu attaches to
  • Position is the menu’s alignment along that edge

For example, TopLeft means the menu is attached to the top edge of trigger and aligned to the left. LeftTop means it is attached to the left edge and aligned to the top.

Variants



TopLeft



TopCenter



TopRight



RightTop



RightCenter



RightBottom



BottomRight



BottomCenter



BottomLeft



LeftBottom



LeftCenter



LeftTop